@@ -246,6 +246,9 @@ class TypeParser:
         original_tokens = tokens
         tokens = tokens[:]
 
+        def fallback():
+            return TypeRef(cls.TRAITS.TAG, "".join(t.text for t in original_tokens))
+
         prefixes, tokens = cls.select_tokens(tokens, cls.TRAITS.ALLOWED_PREFIXES)
         cls.remove_leading_whitespace(prefixes)
 
@@ -259,14 +262,15 @@ class TypeParser:
             nested_types, tokens = cls.nested_types(tokens, driver, parent)
             arg_types, tokens = cls.arg_types(tokens, driver, parent)
         except TypeParseError as e:
-            logger.warning(f"Failed to parse nested types or args: {e}")
+            logger.warning(f"Failed to parse nested types: {e}")
+            return fallback()
 
         suffixes, tokens = cls.select_tokens(tokens, cls.TRAITS.ALLOWED_SUFFIXES)
         cls.remove_trailing_whitespace(suffixes)
 
         if not names:
             logger.warning(f"No name found in `{'`,`'.join(t.text for t in original_tokens)}`")
-            return TypeRef(cls.TRAITS.TAG, "".join(t.text for t in original_tokens))
+            return fallback()
 
         if tokens and any(t.category != TokenCategory.WHITESPACE for t in tokens):
             logger.warning(f"Unexpected trailing token(s) `{'`,`'.join(t.text for t in tokens)}`"
