@@ -174,6 +174,7 @@ async def test_http_package_not_a_tarfile(aiohttp_server, tmp_path):
     with pytest.raises(DownloadError):
         await collect([spec], tmp_path)
 
+
 async def test_http_package_name_interpolation_in_file_names(aiohttp_server, tmp_path):
     server = await start_server(aiohttp_server, web.get("/test/1.0.0/test", xml_file_response))
 
@@ -183,12 +184,14 @@ async def test_http_package_name_interpolation_in_file_names(aiohttp_server, tmp
     spec.include_subdir = "adoc"
     spec.file_names = ["{name}"]
 
-    packages = await collect([spec], tmp_path)
+    await collect([spec], tmp_path)
 
     assert (tmp_path / "test" / "1.0.0" / "xml" / "content.xml").is_file()
 
+
 async def test_http_package_version_interpolation_in_file_names(aiohttp_server, tmp_path):
-    server = await start_server(aiohttp_server, web.get("/test/1.0.0/documentation-1.0.0", xml_file_response))
+    server = await start_server(aiohttp_server,
+                                web.get("/test/1.0.0/documentation-1.0.0", xml_file_response))
 
     spec = HttpPackageSpec("test", "1.0.0",
                            f"http://localhost:{server.port}/{{name}}/{{version}}/{{file_name}}")
@@ -196,12 +199,14 @@ async def test_http_package_version_interpolation_in_file_names(aiohttp_server,
     spec.include_subdir = "adoc"
     spec.file_names = ["documentation-{version}"]
 
-    packages = await collect([spec], tmp_path)
+    await collect([spec], tmp_path)
 
     assert (tmp_path / "test" / "1.0.0" / "xml" / "content.xml").is_file()
 
+
 async def test_http_package_version_and_name_interpolation_in_file_names(aiohttp_server, tmp_path):
-    server = await start_server(aiohttp_server, web.get("/test/1.0.0/test-1.0.0", xml_file_response))
+    server = await start_server(aiohttp_server, web.get("/test/1.0.0/test-1.0.0",
+                                                        xml_file_response))
 
     spec = HttpPackageSpec("test", "1.0.0",
                            f"http://localhost:{server.port}/{{name}}/{{version}}/{{file_name}}")
@@ -209,7 +214,7 @@ async def test_http_package_version_and_name_interpolation_in_file_names(aiohttp
     spec.include_subdir = "adoc"
     spec.file_names = ["{name}-{version}"]
 
-    packages = await collect([spec], tmp_path)
+    await collect([spec], tmp_path)
 
     assert (tmp_path / "test" / "1.0.0" / "xml" / "content.xml").is_file()
 
@@ -722,6 +727,7 @@ version = "1.0.0"
     with pytest.raises(SpecificationError):
         specs_from_file(spec_file)
 
+
 def test_specs_from_file__name_and_version_interpolation(tmp_path):
     spec_file = tmp_path / "spec.toml"
     spec_file.write_text("""
